%define soname 0
%define libname %mklibname %name %soname
%define develname %mklibname -d %name
%define staticname %mklibname -d -s %name
# fife.ppc: W: devel-file-in-non-devel-package /usr/lib/libfife.so <- just a symlink, shouldn't be in -devel. It's used by the client(s).

Name:		fife
Version:	0.3.5
Release:	%mkrel 3
Summary:	Cross-platform game creation framework
Group:		Development/Tools
License:	LGPLv2+
URL:		http://www.fifengine.net
# https://sourceforge.net/projects/fife/files/active/src/fife-0.3.4.tar.gz/download
# removed ext/   -  removed for using system libs instead of shipped
# removed tests/   -  removed for legal issues
Source0:	%{name}_%{version}-clean.tar.gz
# doc/ is not included in sf.net archive, so it was retrieved from https://github.com/fifengine/fifengine/tree/0.3.4
Source1:	%{name}_%{version}-doc.tar.xz
Patch0:		fife-0.3.5-mga-fixdoc.patch
Patch1:		fife-0.3.5-mga-build_against_mesa_10.patch
BuildRequires:	scons
BuildRequires:	SDL-devel
BuildRequires:	boost-devel
BuildRequires:	SDL_ttf-devel
BuildRequires:	SDL_image-devel
BuildRequires:	libvorbis-devel
BuildRequires:	openal-devel
BuildRequires:	swig
BuildRequires:	python-devel
BuildRequires:	zlib-devel
BuildRequires:	mesaglu-devel
BuildRequires:	guichan-devel
BuildRequires:	libpng-devel
BuildRequires:	graphviz
BuildRequires:	libxcursor-devel
BuildRequires:	chrpath
BuildRequires:	guichan-devel
BuildRequires:	tinyxml-devel
Provides:	%{name}-python = %{version}-%{release}
Requires:	%libname = %{version}-%{release}

%description
FIFE is a free, open-source cross-platform game engine, written in C++,
making it highly portable (it supports Linux, Windows and Mac).

This package comes with the game engine only.
The game Unknown Horizons is one of the clients using this engine.

%package -n %libname
Summary:	Shared libs for %{name}
Group:		System/Libraries
Requires:	%{name} = %{version}-%{release}
Conflicts:	fife < 0.3.3-7

%description -n %libname
Shared libs for %{name}.

%package -n %develname
Summary:	Development package for %{name}
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Obsoletes:	%{name}-devel < %{version}-%{release}
Conflicts:	fife < 0.3.3-7

%description -n %develname
Files for development with %{name}.

%package -n %staticname
Summary:	Static library for %{name} development
Group:		Development/C
Requires:	%{develname} = %{version}-%{release}
Provides:	%{name}-static-devel = %{version}-%{release}
Obsoletes:	%{name}-static < %{version}-%{release}

%description -n %staticname
The %{name}-static package includes static libraries needed to develop
programs that use the %{name} library.

%package doc
Summary:	Documentation for %{name}
Group:		Development/Other
BuildRequires:	doxygen
BuildArch:	noarch
Requires:	%{name} = %{version}-%{release}

%description doc
Doxygen generated documentation for %{name}.

%prep
%setup -q -n %{name}_%{version}

# extract the doc archive into the build dir and patch the doxyfile against the missing doxygen/revision
tar -xf %{SOURCE1}
%patch0 -p0
%patch1 -p1

# remove usage of ./ext/ (see line 16 for further informations)
# very dirrty, but it works
sed -i '21d' build/linux2-config.py

# use libdir instead of lib (for 64bit systems)
for l in ./engine/SConscript ./build/linux2-config.py
do
 sed -i "s|'lib'|'%{_lib}'|g" $l
done

# be utf-8 clean, dudes!
for f in ./AUTHORS ./CHANGES ./COPYING ./README
do
 iconv -f iso-8859-1 -t utf-8 $f |sed 's|\r||g' > $f.utf8
 touch -c -r $f $f.utf8
 mv $f.utf8 $f
done

%build
scons . \
      CXXFLAGS='%{optflags}' \
      --enable-debug \
      --enable-rend-grid \
      --enable-rend-camzone \
      --prefix=%{_prefix} \
      --lib-dir=%{_lib} \
      --python-prefix=%{python_sitearch} \
      fife-shared fife-python fife-swig

# Doxygen generated docs
doxygen ./doc/doxygen/doxyfile
rm -f ./doc/doxygen/html/installdox

%install
scons . \
      CXXFLAGS='%{optflags}' \
      DESTDIR=%{buildroot} \
      --prefix=%{_prefix} \
      --lib-dir=%{_lib} \
      --python-prefix=%{python_sitearch} \
      --enable-debug \
      install-all \
      install-dev

# rpath is evil, evil, evil
chrpath --delete %{buildroot}%{_libdir}/lib%{name}.so.%{version}
chrpath --delete %{buildroot}%{python_sitearch}/%{name}/_%{name}.so

# playing a little bit with soname
pushd %{buildroot}%{_libdir}
ln -s lib%{name}.so.%{version} lib%{name}.so.%{soname}
ln -s lib%{name}.so.%{version} lib%{name}.so
popd

mkdir -p %{buildroot}/%{_bindir}/
cat > %{buildroot}/%{_bindir}/%{name}-documentation << EOF
#!/bin/sh
xdg-open file://%{_docdir}/%{name}-doc/index.html
EOF
chmod +x %{buildroot}/%{_bindir}/%{name}-documentation

# fife.ppc: E: non-standard-executable-perm /usr/lib/libfife.so.0 0775
chmod 755 %{buildroot}/%{_libdir}/lib%{name}.so.%{soname}
# fife.ppc: E: non-standard-executable-perm /usr/lib/python2.6/site-packages/fife/_fife.so 0775
chmod 755 %{buildroot}/%{python_sitearch}/%{name}/_%{name}.so

%files
%doc AUTHORS CHANGES COPYING README
%{python_sitearch}/%{name}

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{soname}
%{_libdir}/lib%{name}.so.%{version}

%files -n %develname
%{_libdir}/lib%{name}.so
%{_includedir}/%{name}/

%files -n %staticname
%{_libdir}/lib%{name}.a

%files doc
%doc ./doc/doxygen/html/*
%{_bindir}/%{name}-documentation


%changelog
* Tue Dec 10 2013 zezinho <zezinho> 0.3.5-3.mga4
+ Revision: 556207
- fix build against mesa 10

* Tue Oct 22 2013 umeabot <umeabot> 0.3.5-2.mga4
+ Revision: 544724
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 dams <dams> 0.3.5-1.mga4
+ Revision: 500219
- new version 0.3.5

* Tue Aug 13 2013 akien <akien> 0.3.4-1.mga4
+ Revision: 466155
- Cleaned-up spec file
- Rewrote Description
- Added a secondary source for the doc files which are missing from the upstream sf.net tarball
- Fixed the specfile for fife-doc (wrong path in the bin)

  + dams <dams>
    - new version 0.3.4

* Tue Jul 09 2013 fwang <fwang> 0.3.3-6.mga4
+ Revision: 451777
- rebuild for new boost

* Sun Jun 02 2013 fwang <fwang> 0.3.3-5.mga4
+ Revision: 434724
- rebuild for new libpng

* Thu Apr 11 2013 malo <malo> 0.3.3-4.mga3
+ Revision: 409489
- rebuild for boost 1.53

* Fri Jan 11 2013 umeabot <umeabot> 0.3.3-3.mga3
+ Revision: 350284
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 20 2012 fwang <fwang> 0.3.3-2.mga3
+ Revision: 332934
- rebuild for new boost

* Sat Sep 01 2012 fwang <fwang> 0.3.3-1.mga3
+ Revision: 286931
- specify libdir
- rebuild for new boost

  + dams <dams>
    - update BuildRequires

  + zezinho <zezinho>
    - new version

  + kamil <kamil>
    - rebuild against boost 1.49.0
    - clean .spec

* Mon Nov 28 2011 fwang <fwang> 0.3.2-6.mga2
+ Revision: 173452
- rebuild for new boost

* Sun Sep 11 2011 fwang <fwang> 0.3.2-5.mga2
+ Revision: 142361
- rebuild for new libpng
- fix obsoletes
- libfy the package
- rebuild for new boost

* Thu Jul 14 2011 anaselli <anaselli> 0.3.2-2.mga2
+ Revision: 124145
- fix mageia group, bug #2148

* Wed Jul 13 2011 matteo <matteo> 0.3.2-1.mga2
+ Revision: 123495
- disabled Patch1 to fix compilation error
- BuildRequires updated
- spec file rewritten from scratch

  + stblack <stblack>
    - imported package fife


* Mon Apr 18 2011 Tom Callaway <spot@fedoraproject.org> - 1:0.3.2-4.r2
- update to 0.3.2r2

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:0.3.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sun Feb 06 2011 Thomas Spura <tomspur@fedoraproject.org> - 1:0.3.2-2
- rebuild for new boost

* Fri Nov 26 2010 Simon Wesp <cassmodiah@fedoraproject.org> - 1:0.3.2-1
- Update to 0.3.2

* Wed Aug  4 2010 Thomas Spura <tomspur@fedoraproject.org> - 1:0.3.1-4
- Rebuilt for http://fedoraproject.org/wiki/Features/F14Boost144
- install to sitearch not sitelib
- properly use parallel make

* Wed Jul 21 2010 David Malcolm <dmalcolm@redhat.com> - 1:0.3.1-3
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Thu Apr 29 2010 Thomas Spura <tomspur@fedoraproject.org> - 1:0.3.1-2
- also link against boost_filesystem

* Wed Apr 07 2010 Simon Wesp <cassmodiah@fedoraproject.org> - 1:0.3.1-1
- Update to 0.3.1
 
* Tue Mar 09 2010 Thomas Kowaliczek <linuxdonald@linuxdonald.de> - 1:0.3.0-4
- Fixed Bug #564752
- Thanks for the patch Terje

* Mon Feb 01 2010 Simon Wesp <cassmodiah@fedoraproject.org> - 1:0.3.0-3
- Cosmetical Issues

* Sun Jan 31 2010 Simon Wesp <cassmodiah@fedoraproject.org> - 1:0.3.0-2
- Split devel package and add a static subpackage
- Generate doxygen docs and add a doc subpackage
- Correct epoch usage
- Create and use soname
- Honor CFLAGS
- Correct leaf
- Cleanup

* Wed Jan 27 2010 Simon Wesp <cassmodiah@fedoraproject.org> - 1:0.3.0-1
- Update to 0.3.0

* Tue Jan 21 2010 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.28.r3111svn
- Rebuild for updated boost

* Sat Dec 12 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.27.r3111svn
- Update to r3111

* Thu Oct 08 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.26.r3056svn
- There are no errors revoked spec changes!

* Thu Oct 08 2009 Thomas Kowaliczek <linuxdonald@linuxdonald.de> - 2009.0-0.25.r3056svn
- Update to r3056 and fixed some spec errors

* Tue Sep 29 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.24.r3054svn
- Update to r3054

* Mon Sep 28 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.23.r3053svn
- Update to r3053

* Mon Sep 28 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.22.r3052svn
- Update to r3052

* Sun Sep 27 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.21.r3051svn
- Update to r3051

* Fri Sep 25 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.20.r3050svn
- Update to r3050

* Wed Sep 23 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.19.r3049svn
- Update to r3049

* Tue Sep 22 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.18.r3048svn
- Update to r3048

* Mon Sep 21 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.17.r3047svn
- Update to r3047

* Mon Sep 21 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.16.r3046svn
- Update to r3046

* Mon Sep 21 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.15.r3045svn
- Update to r3045

* Thu Aug 20 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.14.r2955svn
- Update to r2955
- Honor OPTFLAGS

* Sat Jul 11 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.13.r2954svn
- Update to r2954
- Link follow files, because they are equal
   LIBDIR/NAME/engine/libNAME.so
   LIBDIR/NAME/engine/swigwrappers/python/_NAME.so

* Fri Jul 10 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.12.r2953svn
- Update to r2953
- Remove all outcommented spec-code

* Fri Jul 10 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.11.r2952svn
- Correct rpath in source instead of binary

* Fri Jul 10 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.10.r2952svn
- Update to r2952
- Remove ldconfig from POST and POSTUN
- Correct license to LGPLv2+

* Wed Jul 08 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.9.r2951svn
- Update to r2951

* Wed Jul 08 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.8.r2947svn
- Remove tests and clients from source0 for legal issues
- Remove ext from source0 instead of remove via 'rm' in spec - to proof that there is no internal shipped dependency in build process
- Remove doc subpackage

* Sun Jul 05 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.7.r2947svn
- Update to r2947

* Sun Jul 05 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.6.r2946svn
- Update to r2946

* Sun Jul 05 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.5.r2945svn
- Update to r2945

* Sun Jul 05 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.4.r2944svn
- Making RPMLINT happy
- Correct file permissions and add missed shebangs

* Sun Jul 05 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.3.r2944svn
- Update to r2944

* Sat Jun 13 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.2.r2916svn
- Update to r2916

* Sun Mar 29 2009 Simon Wesp <cassmodiah@fedoraproject.org> - 2009.0-0.1.r2761svn
- Initial release
